==> gura-0.6.2-src.tar.gz: gura-0.6.2/src/module-wx/Class_wx_MouseEvent.h <==
//----------------------------------------------------------------------------
// wxMouseEvent
// extracted from mouseevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_MOUSEEVENT_H__
#define __CLASS_WX_MOUSEEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxMouseEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_MouseEvent);

//----------------------------------------------------------------------------
// Object declaration for wxMouseEvent
//----------------------------------------------------------------------------
class Object_wx_MouseEvent : public Object_wx_Event {
public:
	Gura_DeclareObjectAccessor(wx_MouseEvent)
public:
	inline Object_wx_MouseEvent(wxMouseEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(Gura_UserClass(wx_MouseEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_MouseEvent(Class *pClass, wxMouseEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_MouseEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxMouseEvent *GetEntity() {
		return dynamic_cast<wxMouseEvent *>(_pEntity);
	}
	inline wxMouseEvent *ReleaseEntity() {
		wxMouseEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal sig) const {
		if (_pEntity != NULL) return false;
		SetError_InvalidWxObject(sig, "wxMouseEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif

==> gura-0.7.0-src.tar.gz: gura-0.7.0/src/module-wx/Class_wx_MouseEvent.h <==
//----------------------------------------------------------------------------
// wxMouseEvent
// extracted from mouseevt.tex
//----------------------------------------------------------------------------
#ifndef __CLASS_WX_MOUSEEVENT_H__
#define __CLASS_WX_MOUSEEVENT_H__

Gura_BeginModuleScope(wx)

//----------------------------------------------------------------------------
// Class declaration for wxMouseEvent
//----------------------------------------------------------------------------
Gura_DeclareUserClass(wx_MouseEvent);

//----------------------------------------------------------------------------
// Object declaration for wxMouseEvent
//----------------------------------------------------------------------------
class Object_wx_MouseEvent : public Object_wx_Event {
public:
	Gura_DeclareObjectAccessor(wx_MouseEvent)
public:
	inline Object_wx_MouseEvent(wxMouseEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(Gura_UserClass(wx_MouseEvent), pEntity, pObserver, ownerFlag) {}
	inline Object_wx_MouseEvent(Class *pClass, wxMouseEvent *pEntity, GuraObjectObserver *pObserver, bool ownerFlag) :
				Object_wx_Event(pClass, pEntity, pObserver, ownerFlag) {}
	virtual ~Object_wx_MouseEvent();
	virtual Object *Clone() const;
	virtual String ToString(bool exprFlag);
	inline wxMouseEvent *GetEntity() {
		return dynamic_cast<wxMouseEvent *>(_pEntity);
	}
	inline wxMouseEvent *ReleaseEntity() {
		wxMouseEvent *pEntity = GetEntity();
		InvalidateEntity();
		return pEntity;
	}
	inline bool IsInvalid(Signal &sig) const {
		if (_pEntity != nullptr) return false;
		SetError_InvalidWxObject(sig, "wxMouseEvent");
		return true;
	}
};

Gura_EndModuleScope(wx)

#endif
